local DG = DoomGuy

local save_path = "client/doomguy"
local save_file = "client"
local save_extension = "cfg"
local function Save()
	if not consoleplayer then return end

	local file_target = save_path .. "/" .. save_file .. "." .. save_extension
	local file_config = io.openlocal(file_target, "w+")
	file_config:write("config_version: " .. DG.config_version, "\n", "\n")
	for index, cvar in pairs(doomvars) do
		file_config:write(cvar.name .. ": " .. cvar.value, "\n")
	end
	file_config:close()
end

local function Load()
	if not consoleplayer then return end

	local file_target = save_path .. "/" .. save_file .. "." .. save_extension
	local file_config = io.openlocal(file_target, "r")
	if not file_config then -- file check
		print("DoomGuy: Client config file at " .. file_target .. " don't exists, created the file")
		Save()
		return
	end
	
	local total_commands = {}
	local line_index = 0
	for line in file_config:lines() do -- find cvars
		local reader = string.gsub(line, ": ", " ")
		if not string.len(reader) then continue end
		
		local command, value = "", ""
		for data in string.gmatch(reader, "[%a_]") do
			command = $ .. data
		end
		
		for data in string.gmatch(reader, "[%d]") do
			value = $ .. data
		end
		
		if not line_index then -- version check
			if (DG.config_version ~= tonumber(value)) then
				print("DoomGuy: Client config file at " .. file_target .. " was saved in a different config version, still loading the file")
			end
			line_index = $ + 1
			continue
		end
		
		local find_cvar = CV_FindVar(command)
		if not find_cvar then continue end
		if (find_cvar.value == tonumber(value)) then continue end
	
		table.insert(total_commands, {command, tonumber(value)})
		line_index = $ + 1
	end
	
	if not line_index then -- invalid file check
		print("DoomGuy: Client config file at " .. file_target .. " is empty or corrupted, re-created the file")
		Save()
		return
	end
	return total_commands
end

local load_cvars = {}
local loaded = false
addHook("PreThinkFrame", function()
	if loaded then return end
	if not leveltime then return end
	
	if (leveltime == 1) then
		load_cvars = Load() or {}
		return
	end
	
	if (#load_cvars <= 0) then
		loaded = true
		return
	end
	
	local cvar = table.remove(load_cvars)
	local find_cvar = CV_FindVar(cvar[1])
	if not find_cvar then return end
	if (find_cvar.value == cvar[2]) then return end
	COM_BufInsertText(consoleplayer, find_cvar.name .. " " .. cvar[2])
end)

addHook("GameQuit", function()
	Save()
	load_cvars = {}
	loaded = false
end)