local TARGET_VERSION = 202 -- "2.2.x"
local TARGET_SUBVERSION = 13 -- ".13"
if (VERSION < TARGET_VERSION) or ((VERSION == TARGET_VERSION) and (SUBVERSION < TARGET_SUBVERSION)) then
	print(string.format("Exception: SRB2 v%d.%d.%d+ is required for this addon", TARGET_VERSION / 100, TARGET_VERSION % 100, TARGET_SUBVERSION))
	return
end

local DG_VERSION = "v1.1.1"
if DoomGuy then
	print(string.format("Exception: Detected another DoomGuy already loaded (%s) while trying to load this DoomGuy (%s)", DoomGuy.version, DG_VERSION))
	return
end

rawset(_G, "DoomGuy", {
	version = DG_VERSION,
	config_version = 1
})

local DG = DoomGuy
function DG.GetTableKeys(t)
	local i, ks = 1, {}
	for k, v in pairs(t) do
		ks[i] = k
		i = $ + 1
	end
	return ks
end

function DG.PrintTable(t, indent, done)
	done = $ or {}
	indent = $ or 0
	
	local keys = DG.GetTableKeys(t)
	table.sort(keys, function(a, b)
		if (type(a) == "number") and (type(b) == "number") then
			return (a < b)
		end
		return (tostring(a) < tostring(b))
	end)
	done[t] = true

	for i = 1, #keys do
		local key = keys[i]
		local value = t[key]
		local off = string.rep(" ", indent)
		if (type(value) == "table") and not done[value] then
			done[value] = true
			
			print(off .. key .. ": ")
			DG.PrintTable(value, indent + 2, done)
			done[value] = nil
		else
			print(off .. key .. " = " .. tostring(value) .. "")
		end
	end
end

print("Loading DoomGuy " .. DG.version .. "...")
dofile("constants.lua")
dofile("freeslots.lua")
dofile("cvars.lua")
dofile("fonts.lua")
dofile("config.lua")

dofile("Definitions/ammo.lua")
dofile("Definitions/weapons.lua")
dofile("Definitions/Weapons/fist.lua")
dofile("Definitions/Weapons/pistol.lua")
dofile("Definitions/Weapons/shotgun.lua")
dofile("Definitions/Weapons/chaingun.lua")
dofile("Definitions/Weapons/rocketlauncher.lua")
dofile("Definitions/Weapons/plasmarifle.lua")
dofile("Definitions/Weapons/bfg.lua")

dofile("Definitions/pickups.lua")
dofile("Definitions/Pickups/Ammo/clip.lua")
dofile("Definitions/Pickups/Ammo/shell.lua")
dofile("Definitions/Pickups/Ammo/rocket.lua")
dofile("Definitions/Pickups/Ammo/cell.lua")

dofile("Definitions/Pickups/Weapon/pistol.lua")
dofile("Definitions/Pickups/Weapon/shotgun.lua")
dofile("Definitions/Pickups/Weapon/chaingun.lua")
dofile("Definitions/Pickups/Weapon/rocketlauncher.lua")
dofile("Definitions/Pickups/Weapon/plasmarifle.lua")
dofile("Definitions/Pickups/Weapon/bfg9000.lua")
dofile("Definitions/Pickups/Weapon/chainsaw.lua")

dofile("Definitions/Pickups/Powerups/backpack.lua")
dofile("Definitions/Pickups/Powerups/hazardsuit.lua")
dofile("Definitions/Pickups/Powerups/berserk.lua")
dofile("Definitions/Pickups/Powerups/invisibility.lua")

dofile("Definitions/Pickups/Items/medkits.lua")
dofile("Definitions/Pickups/Items/armors.lua")
dofile("Definitions/Pickups/Items/spheres.lua")
dofile("Definitions/Pickups/Items/bonuses.lua")

dofile("Mobjs/bullet.lua")
dofile("Mobjs/damage.lua")

dofile("Player/define.lua")
dofile("Player/spawn.lua")
dofile("Player/hooks.lua")
dofile("Player/thinker.lua")
dofile("Player/damage.lua")
dofile("Player/hud.lua")
print("Loaded DoomGuy " .. DoomGuy.version)